============================
Write Your Own Fantasy Games
============================

.. image:: cover.jpg

`Download the original book <https://drive.google.com/open?id=0Bxv0SsvibDMTel93SThEYkJkZHc>`__

